Author: Shao Mengjie, Liang Qian at 20220803

Email: 1437819081@qq.com; norah-liang@dmicrobe.com

Institute: Hangzhou Digital-Micro Biotech Co.,Ltd

This program is designed for annotation of antimicrobal resistance(AMR), pdif site and pdif-ARGs module in bacteria.

PdifFinder is a python3.X script, running on linux. You can download from github by git clone https://github.com/mjshao06/pdifFinder.git.
